instrumenttools.Accordion
=========================

.. abjad-lineage:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion

.. autoclass:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Accordion.Accordion.Accordion.__repr__
   :noindex:
